==> haskell-yesod-form-1.7.9-149-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-GUMlEsGVy6YAaQxgbLNWHz
key:                  yesod-form-1.7.9-GUMlEsGVy6YAaQxgbLNWHz
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  354fd19a93385e10dc038264bc1b3c46
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-GUMlEsGVy6YAaQxgbLNWHz
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    email-validate-2.3.2.21-6BQ3rNhF1qq9n1JEwG6kxE
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    shakespeare-2.1.7-EQa3S9NEyAK816psNg58s0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    xss-sanitize-0.3.7.2-8cNHDGVpLwFLDuj2Azhm7R
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F
    yesod-persistent-1.6.0.8-1PT3vTEjdj623nY4CmQUQK

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.7.9-151-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-4CfkicQN4Gh1BZtbFMO3Cs
key:                  yesod-form-1.7.9-4CfkicQN4Gh1BZtbFMO3Cs
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  224e775cb6650e321678e21d3c3dd784
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-4CfkicQN4Gh1BZtbFMO3Cs
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    blaze-builder-0.4.4.1-Hto81bisFYkHXSmpZG8kx7
    blaze-html-0.9.2.0-AqjQr4Ps51QD51ybemU3ZY
    blaze-markup-0.8.3.0-K7wUMOM5SyIFeEdepQMdjc
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl
    email-validate-2.3.2.21-LgZsWs8Nbsx9kAip7zihow
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA
    persistent-2.14.5.2-6kV56HNszVGH9bHqEA96Jq
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77
    shakespeare-2.1.7-2tYm0ZnKNHbCMeQLiFCieX text-2.0.2 time-1.12.2
    transformers-0.6.1.0 wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    xss-sanitize-0.3.7.2-ChnRiWcYoX01TL0SXbGH9m
    yesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B
    yesod-persistent-1.6.0.8-I40uFRLoDqjJLxX37rzhLS

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
